@@ -1,6 +1,6 @@
 /* Copyright (c) 2002,2004,2005 Marek Michalkiewicz
    Copyright (c) 2005, Carlos Lamas
-   Copyright (c) 2005, Joerg Wunsch
+   Copyright (c) 2005,2007 Joerg Wunsch
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
@@ -30,7 +30,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: stdint.h,v 1.7 2005/09/13 13:29:54 joerg_wunsch Exp $ */
+/* $Id: stdint.h,v 1.7.2.3 2007/01/23 15:34:58 joerg_wunsch Exp $ */
 
 /*
  * ISO/IEC 9899:1999  7.18 Integer types <stdint.h>
@@ -39,6 +39,7 @@
 #ifndef __STDINT_H_
 #define __STDINT_H_
 
+/** \file */
 /** \defgroup avr_stdint <stdint.h>: Standard Integer Types
     \code #include <stdint.h> \endcode
 
@@ -47,8 +48,13 @@
     Since these typedefs are mandated by the C99 standard, they are preferred
     over rolling your own typedefs.  */
 
+/*
+ * __USING_MINT8 is defined to 1 if the -mint8 option is in effect.
+ */
 #if __INT_MAX__ == 127
 # define __USING_MINT8 1
+#else
+# define __USING_MINT8 0
 #endif
 
 /* Integer types */
@@ -93,12 +99,16 @@ typedef signed long int int32_t;
 typedef unsigned long int uint32_t;
 
 /** \ingroup avr_stdint
-    64-bit signed type. */
+    64-bit signed type.
+    \note This type is not available when the compiler
+    option -mint8 is in effect. */
 
 typedef signed long long int int64_t;
 
 /** \ingroup avr_stdint
-    64-bit unsigned type. */
+    64-bit unsigned type.
+    \note This type is not available when the compiler
+    option -mint8 is in effect. */
 
 typedef unsigned long long int uint64_t;
 
@@ -114,8 +124,10 @@ typedef int int16_t __attribute__ ((__mode__ (__HI__)));
 typedef unsigned int uint16_t __attribute__ ((__mode__ (__HI__)));
 typedef int int32_t __attribute__ ((__mode__ (__SI__)));
 typedef unsigned int uint32_t __attribute__ ((__mode__ (__SI__)));
+#if !__USING_MINT8
 typedef int int64_t __attribute__((__mode__(__DI__)));
 typedef unsigned int uint64_t __attribute__((__mode__(__DI__)));
+#endif
 
 #endif /* defined(__DOXYGEN__) */
 
@@ -171,15 +183,21 @@ typedef int32_t  int_least32_t;
 
 typedef uint32_t uint_least32_t;
 
+#if !__USING_MINT8 || defined(__DOXYGEN__)
 /** \ingroup avr_stdint
-    signed int with at least 64 bits. */
+    signed int with at least 64 bits.
+    \note This type is not available when the compiler
+    option -mint8 is in effect. */
 
 typedef int64_t  int_least64_t;
 
 /** \ingroup avr_stdint
-    unsigned int with at least 64 bits. */
+    unsigned int with at least 64 bits.
+    \note This type is not available when the compiler
+    option -mint8 is in effect. */
 
 typedef uint64_t uint_least64_t;
+#endif
 
 /*@}*/
 
@@ -219,15 +237,21 @@ typedef int32_t int_fast32_t;
 
 typedef uint32_t uint_fast32_t;
 
+#if !__USING_MINT8 || defined(__DOXYGEN__)
 /** \ingroup avr_stdint
-    fastest signed int with at least 64 bits. */
+    fastest signed int with at least 64 bits.
+    \note This type is not available when the compiler
+    option -mint8 is in effect. */
 
 typedef int64_t int_fast64_t;
 
 /** \ingroup avr_stdint
-    fastest unsigned int with at least 64 bits. */
+    fastest unsigned int with at least 64 bits.
+    \note This type is not available when the compiler
+    option -mint8 is in effect. */
 
 typedef uint64_t uint_fast64_t;
+#endif
 
 /*@}*/
 
@@ -238,6 +262,11 @@ typedef uint64_t uint_fast64_t;
 
 /*@{*/
 
+#if __USING_MINT8
+typedef int32_t intmax_t;
+
+typedef uint32_t uintmax_t;
+#else  /* !__USING_MINT8 */
 /** \ingroup avr_stdint
     largest signed int available. */
 
@@ -247,6 +276,7 @@ typedef int64_t intmax_t;
     largest unsigned int available. */
 
 typedef uint64_t uintmax_t;
+#endif /* __USING_MINT8 */
 
 /*@}*/
 
